<?php

namespace Drupal\regions_override;

/**
 * Defines the interface for the page override system.
 */
interface PageOverrideInterface {

  /**
   * Returns the stored value for a given key.
   *
   * @param string $key
   *   The key of the data to retrieve.
   * @param mixed $default
   *   The default value to use if the key is not found.
   *
   * @return mixed
   *   The stored value, or NULL if no value exists.
   */
  public function get($key, $default = NULL);

  /**
   * Saves a value for a given key.
   *
   * @param string $key
   *   The key of the data to store.
   * @param mixed $value
   *   The data to store.
   */
  public function set($key, $value);

  /**
   * Deletes an item.
   *
   * @param string $key
   *   The item name to delete.
   */
  public function delete($key);

  /**
   * Resets the static cache.
   *
   * This is mainly used in testing environments.
   */
  public function resetCache();

  /**
   * Get an override for the current page/route.
   *
   * @return int
   *   The type of override used for the page
   */
  public function getOverride();

  /**
   * Create a key based on the current page entity or route.
   *
   * @return string
   *   A key based on the page entity info or fallback to page route.
   */
  public function generatePageKey();

}
